@@ -3,5 +3,5 @@
 test -n "$srcdir" || srcdir=`dirname "$0"`
 test -n "$srcdir" || srcdir=.
 
-intltoolize --copy --force --automake && autoreconf --force --install --verbose --warnings=all "$srcdir"
+( cd "$srcdir" && intltoolize --copy --force --automake && autoreconf --force --install --verbose --warnings=all "$srcdir" )
 test -n "$NOCONFIGURE" || "$srcdir/configure" "$@"
