@@ -1,5 +1,5 @@
 /* EasyTAG - tag editor for audio files
- * Copyright (C) 2013  David King <amigadave@amigadave.com>
+ * Copyright (C) 2013-2015  David King <amigadave@amigadave.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the Free
@@ -30,13 +30,11 @@ G_BEGIN_DECLS
 
 typedef struct _EtApplicationWindow EtApplicationWindow;
 typedef struct _EtApplicationWindowClass EtApplicationWindowClass;
-typedef struct _EtApplicationWindowPrivate EtApplicationWindowPrivate;
 
 struct _EtApplicationWindow
 {
     /*< private >*/
     GtkApplicationWindow parent_instance;
-    EtApplicationWindowPrivate *priv;
 };
 
 struct _EtApplicationWindowClass
@@ -68,9 +66,9 @@ void et_application_window_browser_set_sensitive (EtApplicationWindow *self, gbo
 void et_application_window_browser_clear (EtApplicationWindow *self);
 void et_application_window_browser_clear_album_model (EtApplicationWindow *self);
 void et_application_window_browser_clear_artist_model (EtApplicationWindow *self);
-void et_application_window_select_dir (EtApplicationWindow *self, const gchar *path);
+void et_application_window_select_dir (EtApplicationWindow *self, GFile *file);
 void et_application_window_select_file_by_et_file (EtApplicationWindow *self, ET_File *ETFile);
-const gchar * et_application_window_get_current_path (EtApplicationWindow *self);
+GFile * et_application_window_get_current_path (EtApplicationWindow *self);
 GtkWidget * et_application_window_get_scan_dialog (EtApplicationWindow *self);
 void et_application_window_apply_changes (EtApplicationWindow *self);
 void et_application_window_browser_entry_set_text (EtApplicationWindow *self, const gchar *text);
