@@ -1,23 +1,22 @@
-/*
- *  EasyTAG - Tag editor for MP3 and Ogg Vorbis files
- *  Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
+/* EasyTAG - tag editor for audio files
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
+ * Copyright (C) 2000-2003  Jerome Couderc <easytag@gmail.com>
  *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ * This program is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the Free
+ * Software Foundation; either version 2 of the License, or (at your option)
+ * any later version.
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
+ * more details.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * You should have received a copy of the GNU General Public License along with
+ * this program; if not, write to the Free Software Foundation, Inc., 51
+ * Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #ifndef ET_BROWSER_H_
 #define ET_BROWSER_H_
 
@@ -69,7 +68,7 @@ enum
 void et_browser_clear_album_model (EtBrowser *self);
 void et_browser_clear_artist_model (EtBrowser *self);
 
-void et_browser_select_dir (EtBrowser *self, const gchar *current_path);
+void et_browser_select_dir (EtBrowser *self, GFile *file);
 void et_browser_reload (EtBrowser *self);
 void et_browser_collapse (EtBrowser *self);
 void et_browser_set_sensitive (EtBrowser *self, gboolean sensitive);
@@ -109,7 +108,7 @@ void et_browser_run_player_for_selection (EtBrowser *self);
 void et_browser_load_default_dir (EtBrowser *self);
 void et_browser_reload_directory (EtBrowser *self);
 void et_browser_set_current_path_default (EtBrowser *self);
-const gchar * et_browser_get_current_path (EtBrowser *self);
+GFile * et_browser_get_current_path (EtBrowser *self);
 
 GtkTreeSelection * et_browser_get_selection (EtBrowser *self);
 
