@@ -3,8 +3,8 @@
 
 #include "enums.h"
 
-/* enumerations from "./src/setting.h" */
-#include "./src/setting.h"
+/* enumerations from "/home/david/checkout/gnome/easytag/src/setting.h" */
+#include "/home/david/checkout/gnome/easytag/src/setting.h"
 GType
 et_cddb_search_category_get_type (void)
 {
