@@ -111,6 +111,7 @@ ET_Comp_Func_Sort_File_By_Descending_Filename (const ET_File *ETFile1,
 /*
  * Comparison function for sorting by ascending disc number.
  */
+/* FIXME: Handle non-numeric disc number. */
 gint
 et_comp_func_sort_file_by_ascending_disc_number (const ET_File *ETFile1,
                                                  const ET_File *ETFile2)
@@ -161,6 +162,7 @@ et_comp_func_sort_file_by_descending_disc_number (const ET_File *ETFile1,
 /*
  * Comparison function for sorting by ascending track number.
  */
+/* FIXME: Handle non-numeric track number. */
 gint
 ET_Comp_Func_Sort_File_By_Ascending_Track_Number (const ET_File *ETFile1,
                                                   const ET_File *ETFile2)
@@ -255,6 +257,50 @@ ET_Comp_Func_Sort_File_By_Descending_Creation_Date (const ET_File *ETFile1,
     return ET_Comp_Func_Sort_File_By_Ascending_Creation_Date(ETFile2,ETFile1);
 }
 
+/*
+ * et_file_list_sort_string:
+ * @str1: a UTF-8 string, or %NULL
+ * @str2: a UTF-8 string to compare against, or %NULL
+ * @file1: an #ET_File corresponding to @str1
+ * @file2: an #ET_File corresponding to @str2
+ * @case_sensitive: whether the sorting should obey case
+ *
+ * Compare two UTF-8 strings, normalizing them before doing so, falling back to
+ * the filenames if the strings are otherwise identical, and obeying the
+ * requested case-sensitivity.
+ *
+ * Returns: an integer less than, equal to, or greater than zero, if str1 is
+ * less than, equal to or greater than str2
+ */
+static gint
+et_file_list_sort_string (const gchar *str1,
+                          const gchar *str2,
+                          const ET_File *file1,
+                          const ET_File *file2,
+                          gboolean case_sensitive)
+{
+    gint result;
+
+    if (case_sensitive)
+    {
+        result = et_normalized_strcmp0 (str1, str1);
+    }
+    else
+    {
+        result = et_normalized_strcasecmp0 (str1, str2);
+    }
+
+    if (result == 0)
+    {
+        /* Secondary criterion. */
+        return ET_Comp_Func_Sort_File_By_Ascending_Filename (file1, file2);
+    }
+    else
+    {
+        /* Primary criterion. */
+        return result;
+    }
+}
 
 /*
  * Comparison function for sorting by ascending title.
@@ -268,28 +314,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Title (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->title == ((File_Tag *)ETFile2->FileTag->data)->title))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->title )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->title )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->title,((File_Tag *)ETFile2->FileTag->data)->title) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->title,((File_Tag *)ETFile2->FileTag->data)->title);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->title,((File_Tag *)ETFile2->FileTag->data)->title) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-      else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->title,((File_Tag *)ETFile2->FileTag->data)->title);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->title,
+                                     ((File_Tag *)ETFile2->FileTag->data)->title,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -315,28 +354,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Artist (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->artist == ((File_Tag *)ETFile2->FileTag->data)->artist))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->artist )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->artist )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->artist,((File_Tag *)ETFile2->FileTag->data)->artist) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->artist,((File_Tag *)ETFile2->FileTag->data)->artist);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->artist,((File_Tag *)ETFile2->FileTag->data)->artist) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->artist,((File_Tag *)ETFile2->FileTag->data)->artist);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->artist,
+                                     ((File_Tag *)ETFile2->FileTag->data)->artist,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -361,28 +393,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Album_Artist (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->album_artist == ((File_Tag *)ETFile2->FileTag->data)->album_artist))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->album_artist )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->album_artist )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->album_artist,((File_Tag *)ETFile2->FileTag->data)->album_artist) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Artist(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->album_artist,((File_Tag *)ETFile2->FileTag->data)->album_artist);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->album_artist,((File_Tag *)ETFile2->FileTag->data)->album_artist) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Artist(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->album_artist,((File_Tag *)ETFile2->FileTag->data)->album_artist);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->album_artist,
+                                     ((File_Tag *)ETFile2->FileTag->data)->album_artist,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -407,28 +432,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Album (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->album == ((File_Tag *)ETFile2->FileTag->data)->album))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->album )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->album )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->album,((File_Tag *)ETFile2->FileTag->data)->album) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->album,((File_Tag *)ETFile2->FileTag->data)->album);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->album,((File_Tag *)ETFile2->FileTag->data)->album) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->album,((File_Tag *)ETFile2->FileTag->data)->album);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->album,
+                                     ((File_Tag *)ETFile2->FileTag->data)->album,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -492,26 +510,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Genre (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->genre == ((File_Tag *)ETFile2->FileTag->data)->genre))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->genre ) return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->genre ) return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
+    if (!ETFile1->FileTag->data)
     {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->genre,((File_Tag *)ETFile2->FileTag->data)->genre) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->genre,((File_Tag *)ETFile2->FileTag->data)->genre);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->genre,((File_Tag *)ETFile2->FileTag->data)->genre) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->genre,((File_Tag *)ETFile2->FileTag->data)->genre);
+        return -1;
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->genre,
+                                     ((File_Tag *)ETFile2->FileTag->data)->genre,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -537,28 +550,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Comment (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->comment == ((File_Tag *)ETFile2->FileTag->data)->comment))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->comment )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->comment )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->comment,((File_Tag *)ETFile2->FileTag->data)->comment) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->comment,((File_Tag *)ETFile2->FileTag->data)->comment);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->comment,((File_Tag *)ETFile2->FileTag->data)->comment) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->comment,((File_Tag *)ETFile2->FileTag->data)->comment);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->comment,
+                                     ((File_Tag *)ETFile2->FileTag->data)->comment,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -584,28 +590,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Composer (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->composer == ((File_Tag *)ETFile2->FileTag->data)->composer))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->composer )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->composer )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->composer,((File_Tag *)ETFile2->FileTag->data)->composer) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->composer,((File_Tag *)ETFile2->FileTag->data)->composer);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->composer,((File_Tag *)ETFile2->FileTag->data)->composer) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->composer,((File_Tag *)ETFile2->FileTag->data)->composer);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->composer,
+                                     ((File_Tag *)ETFile2->FileTag->data)->composer,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -631,28 +630,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Orig_Artist (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->orig_artist == ((File_Tag *)ETFile2->FileTag->data)->orig_artist))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->orig_artist )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->orig_artist )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->orig_artist,((File_Tag *)ETFile2->FileTag->data)->orig_artist) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->orig_artist,((File_Tag *)ETFile2->FileTag->data)->orig_artist);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->orig_artist,((File_Tag *)ETFile2->FileTag->data)->orig_artist) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->orig_artist,((File_Tag *)ETFile2->FileTag->data)->orig_artist);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->orig_artist,
+                                     ((File_Tag *)ETFile2->FileTag->data)->orig_artist,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -678,28 +670,21 @@ ET_Comp_Func_Sort_File_By_Ascending_Copyright (const ET_File *ETFile1,
    ||  (((File_Tag *)ETFile1->FileTag->data)->copyright == ((File_Tag *)ETFile2->FileTag->data)->copyright))
         return 0;
 
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->copyright )
+    if (!ETFile1->FileTag->data)
+    {
         return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->copyright )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->copyright,((File_Tag *)ETFile2->FileTag->data)->copyright) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->copyright,((File_Tag *)ETFile2->FileTag->data)->copyright);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->copyright,((File_Tag *)ETFile2->FileTag->data)->copyright) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->copyright,((File_Tag *)ETFile2->FileTag->data)->copyright);
     }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->copyright,
+                                     ((File_Tag *)ETFile2->FileTag->data)->copyright,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -720,33 +705,29 @@ gint
 ET_Comp_Func_Sort_File_By_Ascending_Url (const ET_File *ETFile1,
                                          const ET_File *ETFile2)
 {
-   // Compare pointers just in case they are the same (e.g. both are NULL)
-   if ((ETFile1->FileTag->data == ETFile2->FileTag->data)
-   ||  (((File_Tag *)ETFile1->FileTag->data)->url == ((File_Tag *)ETFile2->FileTag->data)->url))
+    /* Compare pointers just in case they are the same (e.g. both are NULL). */
+    if ((ETFile1->FileTag->data == ETFile2->FileTag->data)
+        || (((File_Tag *)ETFile1->FileTag->data)->url
+            == ((File_Tag *)ETFile2->FileTag->data)->url))
+    {
         return 0;
-
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->url )
-        return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->url )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->url,((File_Tag *)ETFile2->FileTag->data)->url) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->url,((File_Tag *)ETFile2->FileTag->data)->url);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->url,((File_Tag *)ETFile2->FileTag->data)->url) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->url,((File_Tag *)ETFile2->FileTag->data)->url);
     }
+
+    if (!ETFile1->FileTag->data)
+    {
+        return -1;
+    }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->url,
+                                     ((File_Tag *)ETFile2->FileTag->data)->url,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -767,33 +748,29 @@ gint
 ET_Comp_Func_Sort_File_By_Ascending_Encoded_By (const ET_File *ETFile1,
                                                 const ET_File *ETFile2)
 {
-   // Compare pointers just in case they are the same (e.g. both are NULL)
-   if ((ETFile1->FileTag->data == ETFile2->FileTag->data)
-   ||  (((File_Tag *)ETFile1->FileTag->data)->encoded_by == ((File_Tag *)ETFile2->FileTag->data)->encoded_by))
+    /* Compare pointers just in case they are the same (e.g. both are NULL). */
+    if ((ETFile1->FileTag->data == ETFile2->FileTag->data)
+        || (((File_Tag *)ETFile1->FileTag->data)->encoded_by
+            == ((File_Tag *)ETFile2->FileTag->data)->encoded_by))
+    {
         return 0;
-
-    if ( !ETFile1->FileTag->data || !((File_Tag *)ETFile1->FileTag->data)->encoded_by )
-        return -1;
-    if ( !ETFile2->FileTag->data || !((File_Tag *)ETFile2->FileTag->data)->encoded_by )
-        return 1;
-
-    if (g_settings_get_boolean (MainSettings, "sort-case-sensitive"))
-    {
-        if ( strcmp(((File_Tag *)ETFile1->FileTag->data)->encoded_by,((File_Tag *)ETFile2->FileTag->data)->encoded_by) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcmp(((File_Tag *)ETFile1->FileTag->data)->encoded_by,((File_Tag *)ETFile2->FileTag->data)->encoded_by);
-    }else
-    {
-        if ( strcasecmp(((File_Tag *)ETFile1->FileTag->data)->encoded_by,((File_Tag *)ETFile2->FileTag->data)->encoded_by) == 0 )
-            // Second criterion
-            return ET_Comp_Func_Sort_File_By_Ascending_Filename(ETFile1,ETFile2);
-        else
-            // First criterion
-            return strcasecmp(((File_Tag *)ETFile1->FileTag->data)->encoded_by,((File_Tag *)ETFile2->FileTag->data)->encoded_by);
     }
+
+    if (!ETFile1->FileTag->data)
+    {
+        return -1;
+    }
+
+    if (!ETFile2->FileTag->data)
+    {
+        return 1;
+    }
+
+    return et_file_list_sort_string (((File_Tag *)ETFile1->FileTag->data)->encoded_by,
+                                     ((File_Tag *)ETFile2->FileTag->data)->encoded_by,
+                                     ETFile1, ETFile2,
+                                     g_settings_get_boolean (MainSettings,
+                                                             "sort-case-sensitive"));
 }
 
 /*
@@ -1680,32 +1657,41 @@ ET_File_Data_Has_Redo_Data (const ET_File *ETFile)
 }
 
 /*
- * Ckecks if the current files had been changed but not saved.
+ * Checks if the current files had been changed but not saved.
  * Returns TRUE if the file has been saved.
  * Returns FALSE if some changes haven't been saved.
  */
 gboolean
-ET_Check_If_File_Is_Saved (const ET_File *ETFile)
+et_file_check_saved (const ET_File *ETFile)
 {
-    File_Tag  *FileTag     = NULL;
-    File_Name *FileNameNew = NULL;
+    const File_Tag *FileTag = NULL;
+    const File_Name *FileNameNew = NULL;
 
     g_return_val_if_fail (ETFile != NULL, TRUE);
 
     if (ETFile->FileTag)
-        FileTag     = ETFile->FileTag->data;
+    {
+        FileTag = ETFile->FileTag->data;
+    }
+
     if (ETFile->FileNameNew)
+    {
         FileNameNew = ETFile->FileNameNew->data;
+    }
 
-    // Check if the tag has been changed
-    if ( FileTag && FileTag->saved != TRUE )
+    /* Check if the tag has been changed. */
+    if (FileTag && !FileTag->saved)
+    {
         return FALSE;
+    }
 
-    // Check if name of file has been changed
-    if ( FileNameNew && FileNameNew->saved != TRUE )
+    /* Check if name of file has been changed. */
+    if (FileNameNew && !FileNameNew->saved)
+    {
         return FALSE;
+    }
 
-    // No changes
+    /* No changes. */
     return TRUE;
 }
 
@@ -1748,24 +1734,26 @@ void ET_Mark_File_Name_As_Saved (ET_File *ETFile)
 }
 
 /*
+ * et_file_generate_name:
+ * @ETFile: the file from which to read the existing name
+ * @new_file_name_utf8: UTF-8 encoded new filename
+ *
  * This function generates a new filename using path of the old file and the
  * new name.
- * - ETFile -> old_file_name : "/path_to_file/old_name.ext"
- * - new_file_name_utf8      : "new_name.ext"
- * Returns "/path_to_file/new_name.ext" into allocated data (in UTF-8)!
- * Notes :
- *   - filenames (basemane) musn't exceed 255 characters (i.e. : "new_name.ext")
- *   - ogg filename musn't exceed 255-6 characters as we use mkstemp
+ *
+ * Returns: a newly-allocated filename, in UTF-8
  */
 #if 1
 gchar *
-ET_File_Name_Generate (const ET_File *ETFile,
+et_file_generate_name (const ET_File *ETFile,
                        const gchar *new_file_name_utf8)
 {
     gchar *dirname_utf8;
 
-    if (ETFile && ETFile->FileNameNew->data && new_file_name_utf8
-    && (dirname_utf8=g_path_get_dirname(((File_Name *)ETFile->FileNameNew->data)->value_utf8)) )
+    g_return_val_if_fail (ETFile && ETFile->FileNameNew->data, NULL);
+    g_return_val_if_fail (new_file_name_utf8, NULL);
+
+    if ((dirname_utf8 = g_path_get_dirname (((File_Name *)ETFile->FileNameNew->data)->value_utf8)))
     {
         gchar *extension;
         gchar *new_file_name_path_utf8;
@@ -1776,32 +1764,43 @@ ET_File_Name_Generate (const ET_File *ETFile,
         // Check length of filename (limit ~255 characters)
         //ET_File_Name_Check_Length(ETFile,new_file_name_utf8);
 
-        // If filemame starts with /, it's a full filename with path but without extension
-        if (g_path_is_absolute(new_file_name_utf8))
+        if (g_path_is_absolute (new_file_name_utf8))
         {
-            // We just add the extension
-            new_file_name_path_utf8 = g_strconcat(new_file_name_utf8,extension,NULL);
-        }else
+            /* Just add the extension. */
+            new_file_name_path_utf8 = g_strconcat (new_file_name_utf8,
+                                                   extension, NULL);
+        }
+        else
         {
-            // New path (with filename)
-            if ( strcmp(dirname_utf8,G_DIR_SEPARATOR_S)==0 ) // Root directory?
-                new_file_name_path_utf8 = g_strconcat(dirname_utf8,new_file_name_utf8,extension,NULL);
+            /* New path (with filename). */
+            if (strcmp (dirname_utf8, G_DIR_SEPARATOR_S) == 0)
+            {
+                /* Root directory. */
+                new_file_name_path_utf8 = g_strconcat (dirname_utf8,
+                                                       new_file_name_utf8,
+                                                       extension, NULL);
+            }
             else
-                new_file_name_path_utf8 = g_strconcat(dirname_utf8,G_DIR_SEPARATOR_S,new_file_name_utf8,extension,NULL);
+            {
+                new_file_name_path_utf8 = g_strconcat (dirname_utf8,
+                                                       G_DIR_SEPARATOR_S,
+                                                       new_file_name_utf8,
+                                                       extension, NULL);
+            }
         }
 
         g_free (dirname_utf8);
-        g_free(extension);
-        return new_file_name_path_utf8; // in UTF-8
-    }else
-    {
-        return NULL;
+        g_free (extension);
+
+        return new_file_name_path_utf8;
     }
+
+    return NULL;
 }
 #else
 /* FOR TESTING */
 /* Returns filename in file system encoding */
-gchar *ET_File_Name_Generate (ET_File *ETFile, gchar *new_file_name_utf8)
+gchar *et_file_generate_name (ET_File *ETFile, gchar *new_file_name_utf8)
 {
     gchar *dirname;
 
