@@ -453,23 +453,11 @@ et_file_tag_detect_difference (const File_Tag *FileTag1,
     }
 
     /* Picture */
-    for (pic1 = FileTag1->picture, pic2 = FileTag2->picture; ;
+    for (pic1 = FileTag1->picture, pic2 = FileTag2->picture;
+         pic1 || pic2;
          pic1 = pic1->next, pic2 = pic2->next)
     {
-        if( (pic1 && !pic2) || (!pic1 && pic2) )
-            return TRUE;
-        if (!pic1 || !pic2)
-            break; // => no changes
-        //if (!pic1->data || !pic2->data)
-        //    break; // => no changes
-
-        if (!g_bytes_equal (pic1->bytes, pic2->bytes))
-        {
-            return TRUE;
-        }
-        if (pic1->type != pic2->type)
-            return TRUE;
-        if (et_normalized_strcmp0 (pic1->description, pic2->description) != 0)
+        if (et_picture_detect_difference (pic1, pic2))
         {
             return TRUE;
         }
