@@ -39,6 +39,8 @@ typedef struct
     GtkWidget *file_load_button;
     GtkWidget *file_content_view;
     GtkListStore *file_content_model;
+    GtkWidget *content_reload;
+    GtkWidget *content_reload_menuitem;
     GtkWidget *load_file_content_menu;
     GtkWidget *file_name_view;
     GtkListStore *file_name_model;
@@ -121,7 +123,7 @@ Load_Filename_Set_Filenames (EtLoadFilesDialog *self)
                                                          "rename-replace-illegal-chars"));
 
             /* Build the filename with the path */
-            filename_new_utf8 = ET_File_Name_Generate(ETFile,list_text_tmp);
+            filename_new_utf8 = et_file_generate_name (ETFile, list_text_tmp);
             g_free(list_text_tmp);
 
             /* Set the new filename */
@@ -204,6 +206,8 @@ set_load_button_sensitivity (EtLoadFilesDialog *self,
     if (!file)
     {
         gtk_widget_set_sensitive (priv->file_load_button, FALSE);
+        gtk_widget_set_sensitive (priv->content_reload, FALSE);
+        gtk_widget_set_sensitive (priv->content_reload_menuitem, FALSE);
         return;
     }
 
@@ -214,10 +218,14 @@ set_load_button_sensitivity (EtLoadFilesDialog *self,
     if (info && G_FILE_TYPE_REGULAR == g_file_info_get_file_type (info))
     {
         gtk_widget_set_sensitive (GTK_WIDGET (priv->file_load_button), TRUE);
+        gtk_widget_set_sensitive (priv->content_reload, TRUE);
+        gtk_widget_set_sensitive (priv->content_reload_menuitem, TRUE);
     }
     else
     {
         gtk_widget_set_sensitive (GTK_WIDGET (priv->file_load_button), FALSE);
+        gtk_widget_set_sensitive (priv->content_reload, FALSE);
+        gtk_widget_set_sensitive (priv->content_reload_menuitem, FALSE);
 
         if (!info)
         {
@@ -759,9 +767,9 @@ create_load_file_content_view_popup (EtLoadFilesDialog *self)
 
     MenuItem = gtk_menu_item_new_with_label(_("Reload"));
     gtk_menu_shell_append(GTK_MENU_SHELL(BrowserPopupMenu),MenuItem);
-    g_signal_connect (MenuItem, "activate",
-                      G_CALLBACK (on_load_file_name_view_reload_clicked),
-                      self);
+    g_signal_connect_swapped (MenuItem, "activate",
+                              G_CALLBACK (on_load_file_name_view_reload_clicked),
+                              self);
 
     gtk_widget_show_all(BrowserPopupMenu);
 
@@ -862,12 +870,13 @@ create_load_file_name_view_popup (EtLoadFilesDialog *self)
 
     MenuItem = gtk_menu_item_new_with_label (_("Reload"));
     gtk_menu_shell_append(GTK_MENU_SHELL(BrowserPopupMenu),MenuItem);
-    g_signal_connect (MenuItem, "activate",
-                      G_CALLBACK (on_load_file_content_view_reload_clicked),
-                      self);
+    g_signal_connect_swapped (MenuItem, "activate",
+                              G_CALLBACK (on_load_file_content_view_reload_clicked),
+                              self);
 
     gtk_widget_show_all(BrowserPopupMenu);
 
+    priv->content_reload_menuitem = MenuItem;
     priv->load_file_name_menu = BrowserPopupMenu;
 }
 
@@ -1052,6 +1061,9 @@ et_load_files_dialog_class_init (EtLoadFilesDialogClass *klass)
     gtk_widget_class_bind_template_child_private (widget_class,
                                                   EtLoadFilesDialog,
                                                   file_content_view);
+    gtk_widget_class_bind_template_child_private (widget_class,
+                                                  EtLoadFilesDialog,
+                                                  content_reload);
     gtk_widget_class_bind_template_child_private (widget_class,
                                                   EtLoadFilesDialog,
                                                   file_content_model);
