@@ -183,6 +183,7 @@ Save_List_Store_To_File (const gchar *filename,
                          gint colnum)
 {
     gchar *file_path;
+    gchar *display_path;
     GFile *file;
     GFileOutputStream *ostream;
     GtkTreeIter iter;
@@ -240,12 +241,13 @@ Save_List_Store_To_File (const gchar *filename,
     return;
 
 err:
-    /* FIXME: Format filename encoding for display. */
     file_path = g_file_get_path (file);
+    display_path = g_filename_display_name (file_path);
     Log_Print (LOG_ERROR, _("Cannot write list to file ‘%s’: %s"),
-               file_path, error->message);
+               display_path, error->message);
 
     g_error_free (error);
+    g_free (display_path);
     g_free (file_path);
     g_object_unref (file);
     return;
@@ -298,7 +300,7 @@ Populate_List_Store_From_File (const gchar *filename,
             utf8_line = Try_To_Validate_Utf8_String (line);
             g_free (line);
 
-            if (utf8_line && g_utf8_strlen (utf8_line, -1) > 0)
+            if (!et_str_empty (utf8_line))
             {
                 gtk_list_store_insert_with_values (liststore, NULL, G_MAXINT,
                                                    text_column, utf8_line, -1);
@@ -760,7 +762,8 @@ et_settings_flags_toggle_set (const GValue *value,
     GFlagsValue *flags_value;
     guint mask;
     GVariantBuilder builder;
-    guint flags = g_settings_get_flags (MainSettings, "process-fields");
+    const gchar *flags_key;
+    guint flags;
 
     g_return_val_if_fail (user_data != NULL, NULL);
 
@@ -779,6 +782,9 @@ et_settings_flags_toggle_set (const GValue *value,
         return NULL;
     }
 
+    flags_key = g_object_get_data (G_OBJECT (user_data), "flags-key");
+    flags = g_settings_get_flags (MainSettings, flags_key);
+
     if (g_value_get_boolean (value))
     {
         flags |= flags_value->value;
