@@ -1,5 +1,5 @@
 /* EasyTAG - Tag editor for audio files
- * Copyright (C) 2014  David King <amigadave@amigadave.com>
+ * Copyright (C) 2014-2015  David King <amigadave@amigadave.com>
  * Copyright (C) 2001-2003  Jerome Couderc <easytag@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -75,6 +75,18 @@ static gboolean id3tag_check_if_id3lib_is_buggy (GError **error);
  * Functions *
  *************/
 
+/* et_id3_error_quark:
+ *
+ * Quark for EtID3Error domain.
+ *
+ * Returns: a GQuark for the EtID3Error domain
+ */
+GQuark
+et_id3_error_quark (void)
+{
+    return g_quark_from_static_string ("et-id3-error-quark");
+}
+
 /**
  * et_id3tag_get_tpos_from_file_tag:
  * @FileTag: File_Tag to get disc_number and disc_total from
@@ -190,30 +202,19 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
 
     file = g_file_new_for_path (filename);
 
-    /* FIXME: Handle this in the caller instead. */
     /* This is a protection against a bug in id3lib that enters an infinite
      * loop with corrupted MP3 files (files containing only zeroes) */
     if (!et_id3tag_check_if_file_is_valid (file, error))
     {
-        GtkWidget *msgdialog;
-        gchar *basename;
-        gchar *utf8_basename;
+        if (error)
+        {
+            g_debug ("Error while checking if ID3 tag is valid: %s",
+                     (*error)->message);
+        }
 
-        basename = g_file_get_basename (file);
-        utf8_basename = filename_to_display (basename);
-
-        msgdialog = gtk_message_dialog_new (GTK_WINDOW (MainWindow),
-                                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_CLOSE,
-                                            _("As the following corrupted file ‘%s’ will cause an error in id3lib, it will not be processed"),
-                                            utf8_basename);
-        gtk_window_set_title (GTK_WINDOW (msgdialog), _("Corrupted file"));
-
-        gtk_dialog_run (GTK_DIALOG (msgdialog));
-        gtk_widget_destroy (msgdialog);
-        g_free (basename);
-        g_free (utf8_basename);
+        g_clear_error (error);
+        g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, "%s",
+                     _("Corrupted file"));
         g_object_unref (file);
         return FALSE;
     }
@@ -228,13 +229,34 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
         return FALSE;
     }
 
-    basename_utf8 = g_path_get_basename(filename_utf8);
+#ifdef G_OS_WIN32
+    /* On Windows, id3lib expects filenames to be in the system codepage. */
+    {
+        gchar *locale_filename;
 
-    ID3Tag_Link(id3_tag,filename);
+        locale_filename = g_win32_locale_filename_from_utf8 (filename);
+
+        if (!locale_filename)
+        {
+            g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_INVAL, "%s",
+                         g_strerror (EINVAL));
+            ID3Tag_Delete (id3_tag);
+            g_object_unref (file);
+            return FALSE;
+        }
+
+        ID3Tag_Link (id3_tag, locale_filename);
+
+        g_free (locale_filename);
+    }
+#else
+    ID3Tag_Link (id3_tag, filename);
+#endif
 
     /* Set padding when tag was changed, for faster writing */
     ID3Tag_SetPadding(id3_tag,TRUE);
 
+    basename_utf8 = g_path_get_basename (filename_utf8);
 
     /*********
      * Title *
@@ -657,52 +679,6 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
                              Id3tag_Get_Error_Message (error_update_id3v2));
                 success = FALSE;
             }
-            else
-            {
-                /* See known problem on the top : [ 1016290 ] Unicode16 writing bug.
-                 * When we write the tag in Unicode, we try to check if it was correctly
-                 * written. So to test it : we read again the tag, and then compare
-                 * with the previous one. We check up to find an error (as only some
-                 * characters are affected).
-                 * If the patch to id3lib was applied to fix the problem (tested
-                 * by id3tag_check_if_id3lib_is_buggy) we didn't make the following
-                 * test => OK */
-                if (flag_id3lib_bugged
-                    && g_settings_get_boolean (MainSettings,
-                                               "id3v2-enable-unicode"))
-                {
-                    File_Tag  *FileTag_tmp = et_file_tag_new ();
-
-                    if (id3tag_read_file_tag (file, FileTag_tmp, NULL) == TRUE
-                        && et_file_tag_detect_difference (FileTag,
-                                                          FileTag_tmp) == TRUE)
-                    {
-                        GtkWidget *msgdialog;
-
-                        msgdialog = gtk_message_dialog_new(GTK_WINDOW(MainWindow),
-                                                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                           GTK_MESSAGE_ERROR,
-                                                           GTK_BUTTONS_CLOSE,
-                                                           "%s",
-                                                           _("You have tried to save this tag to Unicode but it was detected that your version of id3lib is buggy"));
-                        gtk_message_dialog_format_secondary_text(GTK_MESSAGE_DIALOG(msgdialog),
-                                                                 _("If you reload this file, some characters in the tag may not be displayed "
-                                                                 "correctly. Please, apply the patch "
-                                                                 "src/id3lib/patch_id3lib_3.8.3_UTF16_writing_bug.diff to id3lib, which is "
-                                                                 "available in the EasyTAG package sources.\nNote that this message will "
-                                                                 "appear only once.\n\nFile: %s"),
-                                                                  filename_utf8);
-
-                        gtk_window_set_title(GTK_WINDOW(msgdialog),_("Buggy id3lib"));
-                        gtk_dialog_run(GTK_DIALOG(msgdialog));
-                        gtk_widget_destroy(msgdialog);
-                        flag_id3lib_bugged = FALSE; // To display the message only one time
-                    }
-
-                    et_file_tag_free (FileTag_tmp);
-                }
-
-            }
         }
         else
         {
@@ -755,6 +731,39 @@ id3tag_write_file_v23tag (const ET_File *ETFile,
         }
     }
 
+    /* Do a one-time check that the id3lib version is not buggy. */
+    if (g_settings_get_boolean (MainSettings, "id3v2-enabled")
+        && number_of_frames != 0 && success)
+    {
+        /* See known problem on the top : [ 1016290 ] Unicode16 writing bug.
+         * When we write the tag in Unicode, we try to check if it was
+         * correctly written. So to test it : we read again the tag, and then
+         * compare with the previous one. We check up to find an error (as only
+         * some characters are affected).
+         * If the patch to id3lib was applied to fix the problem (tested
+         * by id3tag_check_if_id3lib_is_buggy) we didn't make the following
+         * test => OK */
+        if (flag_id3lib_bugged
+            && g_settings_get_boolean (MainSettings,
+                                       "id3v2-enable-unicode"))
+        {
+            File_Tag  *FileTag_tmp = et_file_tag_new ();
+
+            if (id3tag_read_file_tag (file, FileTag_tmp, NULL) == TRUE
+                && et_file_tag_detect_difference (FileTag,
+                                                  FileTag_tmp) == TRUE)
+            {
+                flag_id3lib_bugged = FALSE; /* Report the error only once. */
+                success = FALSE;
+                g_set_error (error, ET_ID3_ERROR,
+                             ET_ID3_ERROR_BUGGY_ID3LIB, "%s",
+                             _("Buggy id3lib"));
+            }
+
+            et_file_tag_free (FileTag_tmp);
+        }
+    }
+
     /* Free allocated data */
     ID3Tag_Delete(id3_tag);
     g_object_unref (file);
@@ -815,27 +824,66 @@ ID3_C_EXPORT size_t ID3Tag_Link_1 (ID3Tag *id3tag, const char *filename)
 {
     size_t offset;
 
+#ifdef G_OS_WIN32
+    /* On Windows, id3lib expects filenames to be in the system codepage. */
+    gchar *locale_filename;
+
+    locale_filename = g_win32_locale_filename_from_utf8 (filename);
+
+    if (!locale_filename)
+    {
+        g_debug ("Error converting filename '%s' to system codepage",
+                 filename);
+        return 0;
+    }
+#endif
+
 #   if (0) // Link the file with the both tags may cause damage to unicode strings
 //#   if ( (ID3LIB_MAJOR >= 3) && (ID3LIB_MINOR >= 8) && (ID3LIB_PATCH >= 1) ) // Same test used in Id3tag_Read_File_Tag to use ID3Tag_HasTagType
         /* No problem of priority, so we link the file with the both tags
          * to manage => ID3Tag_HasTagType works correctly */
-        offset = ID3Tag_LinkWithFlags(id3tag,filename,ID3TT_ID3V1 | ID3TT_ID3V2);
+#ifdef G_OS_WIN32
+        offset = ID3Tag_LinkWithFlags (id3tag, locale_filename,
+                                       ID3TT_ID3V1 | ID3TT_ID3V2);
+#else
+        offset = ID3Tag_LinkWithFlags (id3tag, filename,
+                                       ID3TT_ID3V1 | ID3TT_ID3V2);
+#endif
 #   elif ( (ID3LIB_MAJOR >= 3) && (ID3LIB_MINOR >= 8) )
         /* Version 3.8.0pre2 gives priority to tag id3v1 instead of id3v2, so we
          * try to fix it by linking the file with the id3v2 tag first. This bug
          * was fixed in the final version of 3.8.0 but we can't know it... */
         /* First, try to get the ID3v2 tags */
-        offset = ID3Tag_LinkWithFlags(id3tag,filename,ID3TT_ID3V2);
+#ifdef G_OS_WIN32
+        offset = ID3Tag_LinkWithFlags (id3tag, locale_filename, ID3TT_ID3V2);
+#else
+        offset = ID3Tag_LinkWithFlags (id3tag, filename, ID3TT_ID3V2);
+#endif
+
         if (offset == 0)
         {
             /* No ID3v2 tags available => try to get the ID3v1 tags */
-            offset = ID3Tag_LinkWithFlags(id3tag,filename,ID3TT_ID3V1);
+#ifdef G_OS_WIN32
+            offset = ID3Tag_LinkWithFlags (id3tag, locale_filename,
+                                           ID3TT_ID3V1);
+#else
+            offset = ID3Tag_LinkWithFlags (id3tag, filename, ID3TT_ID3V1);
+#endif
         }
 #   else
         /* Function 'ID3Tag_LinkWithFlags' is not defined up to id3lib-.3.7.13 */
-        offset = ID3Tag_Link(id3tag,filename);
+#ifdef G_OS_WIN32
+        offset = ID3Tag_Link (id3tag, locale_filename);
+#else
+        offset = ID3Tag_Link (id3tag, filename);
+#endif
 #   endif
     //g_print("ID3 TAG SIZE: %d\t%s\n",offset,g_path_get_basename(filename));
+
+#ifdef G_OS_WIN32
+    g_free (locale_filename);
+#endif
+
     return offset;
 }
 
@@ -1072,14 +1120,14 @@ gchar *Id3tag_Get_Field (const ID3Frame *id3_frame, ID3_FieldID id3_fieldid)
     //g_print(">>ID:%d >'%s' (string1:'%s') (num_chars:%d)\n",ID3Field_GetINT(id3_field_encoding),string,string1,num_chars);
 
 out:
-    // In case the conversion fails, try 'filename_to_display' character fix...
+    /* In case the conversion fails, try character fix. */
     if (num_chars && !string1)
     {
         gchar *escaped_str = g_strescape(string, NULL);
         g_debug ("Id3tag_Get_Field: Trying to fix string '%s'…", escaped_str);
         g_free(escaped_str);
 
-        string1 = filename_to_display(string);
+        string1 = g_filename_display_name (string);
 
         /* TODO: Set a GError instead. */
         if (!string1)
