@@ -418,7 +418,7 @@ et_add_file_tags_from_vorbis_comments (vorbis_comment *vc,
             g_slist_foreach (descs, values_list_foreach, &FileTag->comment);
             g_slist_foreach (comments, values_list_foreach, &FileTag->comment);
         }
-        else if (descs && comments)
+        else if (comments)
         {
             FileTag->saved = FALSE;
 
@@ -1096,7 +1096,7 @@ ogg_tag_write_file_tag (const ET_File *ETFile,
         /* Adding MIME string and its length. */
         convert_to_byte_array (strlen (mime), array);
         add_to_guchar_str (ustring, &ustring_len, array, 4);
-        add_to_guchar_str (ustring, &ustring_len, (guchar *)mime,
+        add_to_guchar_str (ustring, &ustring_len, (const guchar *)mime,
                            strlen (mime));
 
         /* Adding picture description. */
